@@ -7,13 +7,6 @@ from ccimport.utils import tempdir
 import os 
 import sys 
 
-def test_cpp_build():
-    source = ccimport.autoimport([Path(__file__).parent / "source.cc"],
-                                 Path(__file__).parent / "source")
-    assert source.sub(2, 1) == 1
-    obj = source.TestClass(5)
-    assert obj.add(3) == 8
-
 
 def test_cpp_exec_build():
     with tempdir() as tempd:
@@ -23,15 +16,16 @@ def test_cpp_exec_build():
         ]
         p2s = {Path(__file__).parent / "some_pch.h": sources}
         pch_to_include = {Path(__file__).parent / "some_pch.h": "some_pch.h"}
+        build_meta = ccimport.BuildMeta(includes=[Path(__file__).parent])
+
         source = ccimport.ccimport(sources,
                                    tempd / "executable",
-                                   includes=[Path(__file__).parent],
+                                   build_meta,
                                    shared=False,
                                    load_library=False,
                                    pch_to_sources=p2s,
                                    pch_to_include=pch_to_include,
-                                   verbose=False,
-                                   objects_folder="objects")
+                                   verbose=False)
 
         output = subprocess.check_output([str(source)])
         assert output.decode("utf-8").strip() == "hello ccimport!"
@@ -51,15 +45,16 @@ def _test_gcc_crosscompile_build():
         ]
         p2s = {Path(__file__).parent / "some_pch.h": sources}
         pch_to_include = {Path(__file__).parent / "some_pch.h": "some_pch.h"}
+        build_meta = ccimport.BuildMeta(includes=[Path(__file__).parent])
+
         source = ccimport.ccimport(sources,
                                    tempd / "executable",
-                                   includes=[Path(__file__).parent],
+                                   build_meta,
                                    shared=True,
                                    load_library=False,
                                    pch_to_sources=p2s,
                                    pch_to_include=pch_to_include,
-                                   verbose=True,
-                                   objects_folder="objects")
+                                   verbose=True)
         print(input("hold"), tempd)
 
         output = subprocess.check_output([str(source)])
